@@ -11,7 +11,7 @@ class ParseTime:
         self._candles = candles_dataframe
 
     def from_human_readable_to_timestamp(self):
-        self._candles["Open_time"] = self._candles.apply(
+        self._candles.loc[:, "Open_time"] = self._candles.apply(
             lambda date_time: ParseDateTime(
                 date_time["Open_time"]
             ).from_human_readable_to_timestamp(),
@@ -19,7 +19,7 @@ class ParseTime:
         )
 
         if "Close_time" in self._candles:
-            self._candles["Close_time"] = self._candles.apply(
+            self._candles.loc[:, "Close_time"] = self._candles.apply(
                 lambda date_time: ParseDateTime(
                     date_time["Close_time"]
                 ).from_human_readable_to_timestamp(),
@@ -27,7 +27,7 @@ class ParseTime:
             )
 
     def from_timestamp_to_human_readable(self):
-        self._candles["Open_time"] = self._candles.apply(
+        self._candles.loc[:, "Open_time"] = self._candles.apply(
             lambda date_time: ParseDateTime(
                 date_time["Open_time"]
             ).from_timestamp_to_human_readable(),
@@ -35,7 +35,7 @@ class ParseTime:
         )
 
         if "Close_time" in self._candles:
-            self._candles["Close_time"] = self._candles.apply(
+            self._candles.loc[:, "Close_time"] = self._candles.apply(
                 lambda date_time: ParseDateTime(
                     date_time["Close_time"]
                 ).from_timestamp_to_human_readable(),
